====================================
Welcome to Octopost's documentation!
====================================

**Octopost** contains a pool of python3 tools for post-processing data obtained with the TDDFT code OCTOPUS[1].

.. warning::

   This project is in a beta phase.

Contents
========

.. toctree::
   :maxdepth: 2

   Introduction <introduction>
   Code Documentation <module>
